abacusai.agent_data_document_info — AbacusAI documentation

# abacusai.agent_data_document_info

## Classes

`AgentDataDocumentInfo` | Information for documents uploaded to agents.

## Module Contents

class abacusai.agent_data_document_info.AgentDataDocumentInfo(client, docId=None, filename=None, mimeType=None, size=None, pageCount=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Information for documents uploaded to agents.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - docId (str) – The docstore Document ID of the document.

    - filename (str) – The file name of the uploaded document.

    - mimeType (str) – The mime type of the uploaded document.

    - size (int) – The total size of the uploaded document.

    - pageCount (int) – The total number of pages in the uploaded document.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict